from __future__ import division, absolute_import, print_function

import numpy as np
from numpy.testing import *

class TestView(TestCase):
    def test_type(self):
        x = np.array([1, 2, 3])
        assert_(isinstance(x.view(np.matrix), np.matrix))

    def test_keywords(self):
        x = np.array([(1, 2)], dtype=[('a', np.int8), ('b', np.int8)])
        # We must be specific about the endianness here:
        y = x.view(dtype='<i2', type=np.matrix)
        assert_array_equal(y, [[513]])

        assert_(isinstance(y, np.matrix))
        assert_equal(y.dtype, np.dtype('<i2'))



"""Small modules to cope with python 2 vs 3 incompatibilities inside
numpy.distutils

"""
from __future__ import division, absolute_import, print_function

import sys

def get_exception():
    return sys.exc_info()[1]



from __future__ import division, absolute_import, print_function

import sys

if sys.version_info[0] < 3:
    from .__version__ import version as __version__
    # Must import local ccompiler ASAP in order to get
    # customized CCompiler.spawn effective.
    from . import ccompiler
    from . import unixccompiler

    from .info import __doc__
    from .npy_pkg_config import *

    try:
        import __config__
        _INSTALLED = True
    except ImportError:
        _INSTALLED = False
else:
    from numpy.distutils.__version__ import version as __version__
    # Must import local ccompiler ASAP in order to get
    # customized CCompiler.spawn effective.
    import numpy.distutils.ccompiler
    import numpy.distutils.unixccompiler

    from numpy.distutils.info import __doc__
    from numpy.distutils.npy_pkg_config import *

    try:
        import numpy.distutils.__config__
        _INSTALLED = True
    except ImportError:
        _INSTALLED = False

if _INSTALLED:
    from numpy.testing import Tester
    test = Tester().test
    bench = Tester().bench
